Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1215)

Unified Diff: third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h

Issue 1492143002: Add support for printing multicol containers, and enable it. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: code review Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h
diff --git a/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h b/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h
index c68d35c8fa593f0e5fbb204e798da818608a75b5..e1ca9abfb033b437823dacbe081332bfcfe7ec5b 100644
--- a/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h
+++ b/third_party/WebKit/Source/core/layout/MultiColumnFragmentainerGroup.h
@@ -44,9 +44,9 @@ public:
LayoutSize offsetFromColumnSet() const;
- // Return the block offset from the enclosing flow thread, if nested. In the coordinate space
- // of the enclosing flow thread.
- LayoutUnit blockOffsetInEnclosingFlowThread() const;
+ // Return the block offset from the enclosing fragmentation context, if nested. In the
+ // coordinate space of the enclosing fragmentation context.
+ LayoutUnit blockOffsetInEnclosingFragmentationContext() const;
// The top of our flow thread portion
LayoutUnit logicalTopInFlowThread() const { return m_logicalTopInFlowThread; }

Powered by Google App Engine
This is Rietveld 408576698